| check_default_colour | R Documentation |
if possible use ink from theme as default colour
check_default_colour(default.colour, theme = NULL)
default.colour |
The value to be checked |
theme |
The theme from where to fetch a replacement value when
|
The replacement value is fetched from the theme only if
'ggplot2' >= 4.0.0 and otherwise "black" is used. NA
values are passed through as they can be used to disable rendering
of grob elements.
A colour definition or NA
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.